SystemOrganization addCategory: #'Rbt-Base'!
SystemOrganization addCategory: #'Rbt-Test'!

Error subclass: #RbtError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rbt-Base'!

Object subclass: #RbtObject
	instanceVariableNames: 'socket port'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rbt-Base'!

RbtObject class
	instanceVariableNames: 'receiveBufferSize sendBufferSize waitingTimeout validInstances isDebugging'!

!RbtObject commentStamp: 'mu 5/26/2005 23:26' prior: 0!
I'm an abstaract class for UDP applications.

I can live between snapshots.!

RbtObject subclass: #RbtClient
	instanceVariableNames: 'targetIp resolveTimeoutSeconds'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rbt-Base'!

RbtClient class
	instanceVariableNames: 'localAddressGetter'!

!RbtClient commentStamp: '<historical>' prior: 0!
I am a client for for UDP applications.

Peer mode:
	client _ RbtClient bind: '192.168.0.2' port: 8833.
	client sendData: 'Hi!!'.

Broadcast mode:
	client _ RbtClient bind: '192.168.0.255' port: 8833.
	client sendData: 'Hi!! Everyone'.
	
	or:

	client _ RbtClient bindForBroadcast: 8833.
	client sendData: 'Hi!! Everyone'.

To see active instances:
	RbtClient validInstances!

!RbtClient class methodsFor: 'instance creation' stamp: 'mu 5/26/2005 23:24'!
bindAround: ipAddress port: portNumber
	"RbtClient bindAround: '192.168.0.2' port: 8833"
	^self new bindAround: ipAddress port: portNumber! !

!RbtClient class methodsFor: 'instance creation' stamp: 'mu 5/26/2005 23:13'!
bindForBroadcast: portNumber
	"RbtClient bindForBroadcast: 8833"
	^self new bindForBroadcast: portNumber! !

!RbtClient class methodsFor: 'instance creation' stamp: 'mu 5/26/2005 23:09'!
bind: ipAddress port: portNumber
	"RbtClient bind: '192.168.0.2' port: 8833"
	^self new bind: ipAddress port: portNumber! !

!RbtClient class methodsFor: 'accessing' stamp: 'mu 4/1/2006 21:10'!
localAddressGetter	
	localAddressGetter ifNil: [localAddressGetter _ NetNameResolver].
	^localAddressGetter! !

!RbtClient class methodsFor: 'accessing' stamp: 'mu 4/1/2006 21:10'!
localAddressGetter: anObject	
	localAddressGetter _ anObject! !

!RbtClient methodsFor: 'private' stamp: 'mu 5/24/2005 18:32'!
addressForName: ipAddressOrHost 
	ipAddressOrHost ifNil: [^nil].
	^ ipAddressOrHost isString
		ifTrue: [NetNameResolver addressForName: ipAddressOrHost timeout: self resolveTimeoutSeconds]
		ifFalse: [ipAddressOrHost]! !

!RbtClient methodsFor: 'actions' stamp: 'mu 5/26/2005 23:15'!
bindAround: ipAddressOrHost port: portNumber 
	| addr |
	addr _ self addressForName: ipAddressOrHost.
	addr ifNil: [self error: 'Invalid ip address or host: ', ipAddressOrHost asString].
	addr isString ifTrue: [self error: 'Cannot broadcast for this host: ', ipAddressOrHost].
	
	addr at: 4 put: 255.
	
	^self bind: addr port: portNumber! !

!RbtClient methodsFor: 'actions' stamp: 'mu 4/1/2006 21:10'!
bindForBroadcast: portNumber 
	^self bindAround: self localAddressGetter localAddressString port: portNumber! !

!RbtClient methodsFor: 'actions' stamp: 'mu 5/26/2005 21:22'!
bind: ipAddressOrHost port: portNumber 
	socket _ self createSocket.
	socket isNil
		ifTrue: [self error: 'Socket not created']
		ifFalse: [| addr | 
			socket setPort: Socket wildcardPort.
			self port: portNumber.
			addr _ self addressForName: ipAddressOrHost.
			addr
				ifNil: [self error: 'Invalid ip address or host: ' , ipAddressOrHost asString].
			self targetIp: addr.
			self register]! !

!RbtClient methodsFor: 'constants' stamp: 'mu 5/23/2005 00:47'!
defaultResolveTimeoutSeconds
	^5! !

!RbtClient methodsFor: 'initialize-release' stamp: 'mu 4/6/2005 16:55'!
initialize
	super initialize.
	! !

!RbtClient methodsFor: 'accessing' stamp: 'mu 4/1/2006 21:09'!
localAddressGetter
	^self class localAddressGetter! !

!RbtClient methodsFor: 'actions' stamp: 'mu 3/9/2006 00:43'!
rebind
	self bind: self targetIp port: self port ! !

!RbtClient methodsFor: 'private' stamp: 'mu 5/26/2005 21:18'!
registrationKey
	^{self targetIp. self port}! !

!RbtClient methodsFor: 'initialize-release' stamp: 'mu 3/9/2006 22:29'!
release
	self releaseSocket.
	self unregister.
	super release! !

!RbtClient methodsFor: 'accessing' stamp: 'mu 5/23/2005 00:47'!
resolveTimeoutSeconds
	resolveTimeoutSeconds
		ifNil: [resolveTimeoutSeconds _ self defaultResolveTimeoutSeconds].
	^ resolveTimeoutSeconds! !

!RbtClient methodsFor: 'accessing' stamp: 'mu 5/23/2005 00:45'!
resolveTimeoutSeconds: seconds
	resolveTimeoutSeconds _ seconds! !

!RbtClient methodsFor: 'actions' stamp: 'mu 3/9/2006 22:15'!
sendData: stringOrByteArray 
	| toSendSize sendData |
	sendData _ stringOrByteArray asByteArray.
	toSendSize _ stringOrByteArray size.
	self isValid ifFalse: [self rebind].
	[| sentSize | 
	sentSize _ socket
				sendData: sendData
				toHost: self targetIp
				port: self port.
	sentSize < toSendSize
		ifTrue: [^ self error: 'Too big data: ' , toSendSize asString]]
		on: Error
		do: [:ex | (self isPrimitiveFailedMessage: ex messageText)
				ifTrue: [self debug: ex description]
				ifFalse: [self error: ex description]]! !

!RbtClient methodsFor: 'actions-startup' stamp: 'mu 3/9/2006 20:38'!
sleep
	self releaseSocket.

	! !

!RbtClient methodsFor: 'accessing' stamp: 'mu 4/6/2005 16:54'!
targetIp
	^targetIp! !

!RbtClient methodsFor: 'accessing' stamp: 'mu 4/6/2005 16:54'!
targetIp: ipAddress
	targetIp _ ipAddress! !

!RbtClient methodsFor: 'actions-startup' stamp: 'mu 3/9/2006 20:38'!
wakeUp
	self rebind.

	! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 3/9/2006 19:40'!
allValidInstances
	^self allSubclasses inject: Set new into: [:sum :each |
		sum addAll: each validInstances; yourself
	]! !

!RbtObject class methodsFor: 'defaults' stamp: 'mu 5/22/2003 00:31'!
defaultPort
	^10244! !

!RbtObject class methodsFor: 'defaults' stamp: 'mu 5/21/2003 23:01'!
defaultReceiveBufferSize
	^1024! !

!RbtObject class methodsFor: 'defaults' stamp: 'mu 5/21/2003 23:01'!
defaultSendBufferSize
	^1024! !

!RbtObject class methodsFor: 'defaults' stamp: 'mu 5/26/2005 18:20'!
defaultWaitingTimeout
	^8! !

!RbtObject class methodsFor: 'class initialization' stamp: 'mu 3/9/2006 19:42'!
initialize
	"RbtObject initialize"
	self == RbtObject
		ifTrue: [Smalltalk addToShutDownList: self.
			Smalltalk addToStartUpList: self]! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/26/2005 19:48'!
isDebugging
	isDebugging ifNil: [isDebugging _ false].
	^isDebugging! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/22/2005 23:02'!
isDebugging: aBoolean
	isDebugging _ aBoolean == true! !

!RbtObject class methodsFor: 'class initialization' stamp: 'mu 3/9/2006 19:42'!
obsolete
	self == RbtObject
		ifTrue: [self releaseAllValidInstances.
			Smalltalk removeFromShutDownList: self.
			Smalltalk removeFromStartUpList: self]! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/21/2003 23:02'!
receiveBufferSize
	receiveBufferSize ifNil: [receiveBufferSize _ self defaultReceiveBufferSize].
	^receiveBufferSize! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/21/2003 21:45'!
receiveBufferSize: anInteger
	receiveBufferSize _ anInteger! !

!RbtObject class methodsFor: 'class initialization' stamp: 'mu 3/9/2006 19:59'!
releaseAllValidInstances
	self allSubclasses do: [:each | each releaseValidInstances]! !

!RbtObject class methodsFor: 'class initialization' stamp: 'mu 3/9/2006 19:59'!
releaseValidInstances
	self validInstances do: [:each | each release].
	validInstances _ nil.! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/21/2003 23:02'!
sendBufferSize
	sendBufferSize ifNil: [sendBufferSize _  self defaultSendBufferSize].
	^sendBufferSize! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/21/2003 21:45'!
sendBufferSize: anInteger
	sendBufferSize _ anInteger! !

!RbtObject class methodsFor: 'system-startup' stamp: 'mu 3/9/2006 19:39'!
shutDown
	self allValidInstances do: [:each | each sleep].! !

!RbtObject class methodsFor: 'system-startup' stamp: 'mu 3/9/2006 19:38'!
startUp
	self allValidInstances do: [:each | each wakeUp].! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 3/9/2006 09:55'!
validInstances
	"self validInstances"
	validInstances ifNil: [validInstances _ WeakRegistry new].
	^validInstances! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/21/2003 23:02'!
waitingTimeout
	waitingTimeout ifNil: [waitingTimeout _ self defaultWaitingTimeout].
	^waitingTimeout! !

!RbtObject class methodsFor: 'accessing' stamp: 'mu 5/21/2003 22:15'!
waitingTimeout: anInteger
	waitingTimeout _ anInteger! !

!RbtObject methodsFor: 'private' stamp: 'mu 1/22/2006 22:09'!
basicCreateSocket
	socket _ Socket udpCreateIfFail: [].
	^socket
	! !

!RbtObject methodsFor: 'actions' stamp: 'mu 1/22/2006 22:22'!
createSocket
	"Default is broadcast - you can override to use unicast or multicast"
	^self createSocketBy: #broadcast.
	! !

!RbtObject methodsFor: 'actions' stamp: 'mu 1/22/2006 22:11'!
createSocketBy: optionSymbol
	socket _ self basicCreateSocket.
	socket ifNil:[^nil].
	self setSocketOptionsBy: optionSymbol.
	^socket
	! !

!RbtObject methodsFor: 'debugging' stamp: 'mu 5/22/2005 23:04'!
debug: message 
	self class isDebugging
		ifTrue: [Transcript cr; show: message]! !

!RbtObject methodsFor: 'private' stamp: 'mu 5/22/2005 22:56'!
error: message
	RbtError signal: message asString! !

!RbtObject methodsFor: 'finalization' stamp: 'mu 3/9/2006 20:38'!
finalize
	self release! !

!RbtObject methodsFor: 'initialize-release' stamp: 'mu 5/21/2003 22:30'!
initialize
	Socket initializeNetwork.
	
	! !

!RbtObject methodsFor: 'private' stamp: 'mu 7/7/2005 22:10'!
isPrimitiveFailedMessage: aString 
	^ '*a primitive has failed*' match: aString! !

!RbtObject methodsFor: 'testing' stamp: 'mu 3/9/2006 00:41'!
isValid
	self socket ifNil: [^false].
	^self socket isValid! !

!RbtObject methodsFor: 'accessing' stamp: 'mu 5/22/2003 00:32'!
port
	port ifNil:[ port _ self class defaultPort].
	^port! !

!RbtObject methodsFor: 'accessing' stamp: 'mu 5/14/2003 18:40'!
port: anInteger
	port _ anInteger! !

!RbtObject methodsFor: 'printing' stamp: 'mu 3/9/2006 09:28'!
printOn: aStream
	aStream nextPutAll: 'a ', self className, '['.
	socket ifNotNilDo: [:s | aStream space; nextPutAll: s printString].
	port ifNotNilDo: [:p | aStream space; nextPutAll: p printString].
	aStream nextPutAll: ']'! !

!RbtObject methodsFor: 'private' stamp: 'mu 3/9/2006 09:57'!
register
	self class validInstances add: self! !

!RbtObject methodsFor: 'private' stamp: 'mu 5/26/2005 21:17'!
registrationKey
	^self identityHash! !

!RbtObject methodsFor: 'initialize-release' stamp: 'mu 3/9/2006 22:29'!
release
	socket _ nil! !

!RbtObject methodsFor: 'actions' stamp: 'mu 5/21/2003 22:51'!
releaseSocket
	socket ifNotNil: [socket closeAndDestroy.].
	socket _ nil! !

!RbtObject methodsFor: 'options' stamp: 'mu 1/22/2006 21:45'!
setBroadcast
	socket ifNil: [^self].
	socket setOption: 'SO_BROADCAST' value: 1.
	
	
	! !

!RbtObject methodsFor: 'options' stamp: 'mu 1/22/2006 21:48'!
setDefaultOptions
	socket ifNil: [^self].
	socket setOption: 'SO_SNDBUF' value: self class sendBufferSize asString.
	socket setOption: 'SO_RCVBUF' value: self class receiveBufferSize asString. 
	
	
	! !

!RbtObject methodsFor: 'options' stamp: 'mu 1/22/2006 21:53'!
setSocketOptionsBy: aSymbol
	"unicast, multicast, broadcast"
	socket ifNil: [^self].
	self setDefaultOptions.
	aSymbol == #broadcast ifTrue: [self setBroadcast].
	
	
	! !

!RbtObject methodsFor: 'actions' stamp: 'mu 5/26/2005 21:24'!
sleep
	self subclassResponsibility! !

!RbtObject methodsFor: 'accessing' stamp: 'mu 5/26/2005 18:21'!
socket
	^socket! !

!RbtObject methodsFor: 'private' stamp: 'mu 3/9/2006 10:01'!
unregister
	self class validInstances remove: self ifAbsent:[]! !

!RbtObject methodsFor: 'actions' stamp: 'mu 5/26/2005 21:24'!
wakeUp
	self subclassResponsibility! !

RbtObject subclass: #RbtServer
	instanceVariableNames: 'isRunning listeningProcess idlingMilliseconds handlerBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rbt-Base'!

!RbtServer commentStamp: 'mu 5/26/2005 23:07' prior: 0!
I'm an abstaract server for UDP applications.

Please override RbtServer>>handleReceived:.

To see active instances:
	RbtServer validInstances!

!RbtServer class methodsFor: 'instance creation' stamp: 'mu 5/22/2005 23:34'!
startOn: port
	"RbtServer startOn: 8867"
	^self new startOn: port! !

!RbtServer class methodsFor: 'instance creation' stamp: 'mu 1/22/2006 22:42'!
startOn: port member: memberAddress 
	"###224.0.0.0 - 239.255.255.255 must be used###"
	"RbtServer startOn: 8867 member: '239.255.255.250'"
	^ self new startOn: port member: memberAddress! !

!RbtServer methodsFor: 'private' stamp: 'mu 1/22/2006 22:12'!
basicStartOn: aPort by: optionSymbol
	self isRunning
		ifTrue: [^ self].
	socket _ self createSocketBy: optionSymbol.
	socket
		ifNotNil: [port _ aPort.
			socket setPort: port.
			isRunning _ true.
			[self listenLoop] fork.
			self register]! !

!RbtServer methodsFor: 'constants' stamp: 'mu 5/23/2005 00:37'!
defaultIdlingMilliSeconds
	^80! !

!RbtServer methodsFor: 'private' stamp: 'mu 5/22/2003 00:54'!
ensureProcessTerminated
	listeningProcess
		ifNotNil: [listeningProcess terminate].
	! !

!RbtServer methodsFor: 'listening' stamp: 'mu 5/23/2005 00:57'!
getDataOn: buffer 
	| receivedSize receivedData |
	receivedSize _ [socket receiveDataInto: buffer]
				on: Error
				do: [:ex | 
					self debug: '##receive buffer size overrun'.
					ex return: 0].
	^ receivedSize = 0
		ifFalse: [receivedData _ buffer copyFrom: 1 to: receivedSize.
			receivedData]! !

!RbtServer methodsFor: 'receiving' stamp: 'mu 5/26/2005 23:42'!
handleReceived: messageObject
	"Override"
	"self debug: 'handleReceived: ', messageObject"
	
	^self handlerBlock value: messageObject! !

!RbtServer methodsFor: 'accessing' stamp: 'mu 5/26/2005 23:41'!
handlerBlock
	handlerBlock ifNil: [handlerBlock _ [:data | ]].
	^handlerBlock! !

!RbtServer methodsFor: 'accessing' stamp: 'mu 5/26/2005 23:42'!
handlerBlock: aBlock
	handlerBlock _ aBlock! !

!RbtServer methodsFor: 'accessing' stamp: 'mu 5/23/2005 00:39'!
idlingMilliSeconds
	idlingMilliseconds ifNil: [idlingMilliseconds _ self defaultIdlingMilliSeconds].
	^idlingMilliseconds! !

!RbtServer methodsFor: 'accessing' stamp: 'mu 5/23/2005 00:39'!
idlingMilliSeconds: milliSeconds
	idlingMilliseconds _ milliSeconds! !

!RbtServer methodsFor: 'initialize-release' stamp: 'mu 5/22/2005 22:44'!
initialize
	super initialize.
	isRunning _ false.
	listeningProcess _ nil.
	
	
	! !

!RbtServer methodsFor: 'testing' stamp: 'mu 10/5/2005 10:53'!
isRunning
	^isRunning & socket notNil! !

!RbtServer methodsFor: 'accessing' stamp: 'mu 5/14/2003 18:43'!
isRunning: aBoolean
	isRunning _ aBoolean! !

!RbtServer methodsFor: 'listening' stamp: 'mu 5/26/2005 19:56'!
listenLoop
	self ensureProcessTerminated.
	listeningProcess _ [| buffer | 
			buffer _ String new: self class receiveBufferSize.
			[[isRunning
					and: [socket notNil]]
				whileTrue: [| coming | 
					coming _ [self waitForData.
							true]
								on: ConnectionClosed , ConnectionTimedOut
								do: [:ex | 
									(Delay forMilliseconds: self idlingMilliSeconds) wait.
									ex return: false].
					coming
						ifTrue: [| receivedData | 
							receivedData _ self getDataOn: buffer.
							receivedData
								ifNotNil: [self handleReceived: receivedData]]]]
				ensure: [self releaseSocket]]
				forkAt: Processor userInterruptPriority! !

!RbtServer methodsFor: 'private' stamp: 'mu 5/26/2005 21:17'!
registrationKey
	^self port! !

!RbtServer methodsFor: 'initialize-release' stamp: 'mu 3/9/2006 22:29'!
release
	self stop.
	listeningProcess _ handlerBlock _ nil.
	super release! !

!RbtServer methodsFor: 'actions' stamp: 'mu 5/26/2005 21:23'!
restart
	self wakeUp! !

!RbtServer methodsFor: 'actions-startup' stamp: 'mu 3/9/2006 20:37'!
sleep
	isRunning _ false.
	self ensureProcessTerminated.
	! !

!RbtServer methodsFor: 'actions' stamp: 'mu 5/22/2003 00:20'!
start
	self startOn: self port! !

!RbtServer methodsFor: 'actions' stamp: 'mu 1/22/2006 22:13'!
startOn: aPort 
	self basicStartOn: aPort by: #broadcast! !

!RbtServer methodsFor: 'actions' stamp: 'mu 1/22/2006 22:36'!
startOn: portNumber member: memberAddressString 
	| memberAddress |
	self basicStartOn: portNumber by: #multicast.
	"multicast option must be set after running -(sort of tricky part)"


	memberAddress _ NetNameResolver addressFromString: memberAddressString.
	memberAddress ifNil: [self error: 'Bad address format'].

	socket
		ifNotNil: [socket setOption: 'IP_ADD_MEMBERSHIP' value: memberAddress]! !

!RbtServer methodsFor: 'actions' stamp: 'mu 3/9/2006 20:00'!
stop
	isRunning _ false.
	self ensureProcessTerminated.
	self unregister.
	! !

!RbtServer methodsFor: 'private' stamp: 'mu 7/7/2005 22:11'!
waitForData
	[socket waitForDataFor: self class waitingTimeout]
		on: Error
		do: [:ex | 
			(self isPrimitiveFailedMessage: ex messageText)
				ifTrue: [self release]
				ifFalse: [ex pass]]! !

!RbtServer methodsFor: 'actions-startup' stamp: 'mu 3/9/2006 20:37'!
wakeUp
	self stop.
	self start.
	! !

RbtServer subclass: #RbtTestServer
	instanceVariableNames: 'receivedObjects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rbt-Test'!

!RbtTestServer methodsFor: 'receiving' stamp: 'mu 5/26/2005 18:36'!
handleReceived: messageObject
	receivedObjects add: messageObject.
	! !

!RbtTestServer methodsFor: 'initialize-release' stamp: 'mu 5/26/2005 18:35'!
initialize
	super initialize.
	receivedObjects _ OrderedCollection new! !

!RbtTestServer methodsFor: 'accessing' stamp: 'mu 5/26/2005 18:35'!
receivedObjects
	^receivedObjects! !

TestCase subclass: #RbtSimpleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Rbt-Test'!

!RbtSimpleTest methodsFor: 'Testing' stamp: 'mu 5/26/2005 23:25'!
testSendBroadcast
	"self debug: #testSendBroadcast"
	| server client client2 |
	[server _ RbtTestServer startOn: 43235.
	self
		should: [server isRunning].
	client _ RbtClient bindAround: NetNameResolver localAddressString port: 43235.
	client sendData: 'test1'.
	client sendData: 'test2'.
	client2 _ RbtClient bindAround: 'localhost' port: 43235.
	client2 sendData: 'test3'.
	(Delay forSeconds: 1) wait.
	self
		should: [server receivedObjects first = 'test1'].
	self
		should: [server receivedObjects second = 'test2'].
	self
		should: [server receivedObjects third = 'test3']]
		ensure: [client
				ifNotNil: [client release].
			client2
				ifNotNil: [client2 release].
			server
				ifNotNil: [server stop]]! !

!RbtSimpleTest methodsFor: 'Testing' stamp: 'mu 1/22/2006 22:45'!
testSendMulticast
	"self debug: #testSendMulticast"
	| memberAddress server client client2  |
	memberAddress _ '239.255.255.111'.
	[server _ RbtTestServer startOn: 43239 member: memberAddress.
	self
		should: [server isRunning].
	client _ RbtClient bind: memberAddress port: 43239.
	client sendData: 'test1'.
	client sendData: 'test2'.
	client2 _ RbtClient bind: memberAddress port: 43239.
	client2 sendData: 'test3'.
	(Delay forSeconds: 1) wait.
	self
		should: [server receivedObjects first = 'test1'].
	self
		should: [server receivedObjects second = 'test2'].
	self
		should: [server receivedObjects third = 'test3']]
		ensure: [client
				ifNotNil: [client release].
			client2
				ifNotNil: [client2 release].
			server
				ifNotNil: [server stop]]! !

!RbtSimpleTest methodsFor: 'Testing' stamp: 'mu 5/26/2005 18:51'!
testSendPeer
	"self debug: #testSendPeer"
	| server client client2 |
	[server _ RbtTestServer startOn: 43234.
	self
		should: [server isRunning].
	client _ RbtClient bind: '127.0.0.1' port: 43234.
	client sendData: 'test1'.
	client sendData: 'test2'.
	client2 _ RbtClient bind: NetNameResolver localAddressString port: 43234.
	client2 sendData: 'test3'.
	(Delay forSeconds: 1) wait.
	self
		should: [server receivedObjects first = 'test1'].
	self
		should: [server receivedObjects second = 'test2'].
	self
		should: [server receivedObjects third = 'test3']]
		ensure: [client
				ifNotNil: [client release].
			client2
				ifNotNil: [client2 release].
			server
				ifNotNil: [server stop]]! !

!RbtSimpleTest methodsFor: 'Testing' stamp: 'mu 5/26/2005 18:59'!
testSendPeerBulk
	"self debug: #testSendPeerBulk"
	| server client bulk1 bulk2 |
	[server _ RbtTestServer startOn: 43234.
	self
		should: [server isRunning].
	client _ RbtClient bind: '127.0.0.1' port: 43234.
	bulk1 _ (String new: 200 withAll: $x) copy.
	client sendData: bulk1.
	bulk2 _ (String new: 1024 withAll: $y) copy. "Max for RBT"
	client sendData: bulk2.
	(Delay forSeconds: 1) wait.
	self
		should: [server receivedObjects first = bulk1].
	self
		should: [server receivedObjects second = bulk2]]
		ensure: [client
				ifNotNil: [client release].
			server
				ifNotNil: [server stop]]! !

!RbtSimpleTest methodsFor: 'Testing' stamp: 'mu 5/26/2005 18:27'!
testServerStartStop
	"self debug: #testServerStartStop"
	| server |
	server _ RbtServer startOn: 43234.
	self should: [server isRunning].
	self should: [server port = 43234].
	server stop.
	self should: [server isRunning not].! !
RbtObject initialize!
